@@ -13,6 +13,7 @@ mod common_args;
 mod r#enum;
 mod error;
 mod multipart;
+mod newtype;
 mod oauth_scopes;
 mod object;
 mod oneof;
@@ -138,3 +139,12 @@ pub fn Webhook(args: TokenStream, input: TokenStream) -> TokenStream {
         Err(err) => err.write_errors().into(),
     }
 }
+
+#[proc_macro_derive(NewType, attributes(oai))]
+pub fn derive_new_type(input: TokenStream) -> TokenStream {
+    let args = parse_macro_input!(input as DeriveInput);
+    match newtype::generate(args) {
+        Ok(stream) => stream.into(),
+        Err(err) => err.write_errors().into(),
+    }
+}
